@@ -1,4 +1,5 @@
 use crate::mnemonic::Language;
+use crate::utils::FeeInfo;
 use base64::DecodeError as Base64DecodeError;
 use cosmos_sdk_proto::cosmos::base::abci::v1beta1::TxResponse;
 use fmt::Debug;
@@ -31,6 +32,7 @@ pub enum CosmosGrpcError {
     InvalidPrefix,
     NoBlockProduced { time: Duration },
     TransactionFailed { tx: TxResponse, time: Duration },
+    InsufficientFees { fee_info: FeeInfo },
 }
 
 impl Display for CosmosGrpcError {
@@ -76,6 +78,9 @@ impl Display for CosmosGrpcError {
                     time.as_millis()
                 )
             }
+            CosmosGrpcError::InsufficientFees { fee_info } => {
+                write!(f, "Insufficient fees or gas for transaction {:?}", fee_info)
+            }
         }
     }
 }
